==> open-xchange-drive-comet_7.4.0.orig.tar.bz2: open-xchange-drive-comet-7.4.0/com.openexchange.drive.json.comet/src/com/openexchange/drive/json/comet/osgi/DriveJsonCometActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.drive.json.comet.osgi;

import org.apache.commons.logging.Log;
import org.glassfish.grizzly.comet.CometContext;
import com.openexchange.config.ConfigurationService;
import com.openexchange.drive.events.DriveEvent;
import com.openexchange.drive.json.LongPollingListenerFactory;
import com.openexchange.drive.json.comet.internal.CometListenerFactory;
import com.openexchange.http.grizzly.service.comet.CometContextService;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link DriveJsonCometActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class DriveJsonCometActivator extends HousekeepingActivator {

    private static final Log LOG = com.openexchange.log.Log.loggerFor(DriveJsonCometActivator.class);
    private static final String TOPIC = "/drive/listen";

    /**
     * Initializes a new {@link DriveJsonCometActivator}.
     */
    public DriveJsonCometActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class, CometContextService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        LOG.info("starting bundle: com.openexchange.drive.json.comet");
        long expirationDelay = getService(ConfigurationService.class).getIntProperty("com.openexchange.drive.listenTimeout", 90 * 1000);
        CometContext<DriveEvent> cometContext = getService(CometContextService.class).register(TOPIC);
        cometContext.setExpirationDelay(expirationDelay);
        registerService(LongPollingListenerFactory.class, new CometListenerFactory(cometContext));
    }

    @Override
    protected void stopBundle() throws Exception {
        LOG.info("stopping bundle: com.openexchange.drive.json.comet");
        try {
            CometContextService cometContextService = getService(CometContextService.class);
            if (null != cometContextService) {
                cometContextService.deregister(TOPIC);
            }
        } catch (RuntimeException e) {
            LOG.warn("Error unregistering comet context", e);
        }
        super.stopBundle();
    }

}

==> open-xchange-drive-comet_7.4.2.orig.tar.bz2: open-xchange-drive-comet-7.4.2/com.openexchange.drive.json.comet/src/com/openexchange/drive/json/comet/osgi/DriveJsonCometActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.drive.json.comet.osgi;

import org.glassfish.grizzly.comet.CometContext;
import com.openexchange.config.ConfigurationService;
import com.openexchange.drive.events.DriveEvent;
import com.openexchange.drive.json.LongPollingListenerFactory;
import com.openexchange.drive.json.comet.internal.CometListenerFactory;
import com.openexchange.http.grizzly.service.comet.CometContextService;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link DriveJsonCometActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class DriveJsonCometActivator extends HousekeepingActivator {

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DriveJsonCometActivator.class);
    private static final String TOPIC = "/drive/listen";

    /**
     * Initializes a new {@link DriveJsonCometActivator}.
     */
    public DriveJsonCometActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ConfigurationService.class, CometContextService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        LOG.info("starting bundle: com.openexchange.drive.json.comet");
        long expirationDelay = getService(ConfigurationService.class).getIntProperty("com.openexchange.drive.listenTimeout", 90 * 1000);
        CometContext<DriveEvent> cometContext = getService(CometContextService.class).register(TOPIC);
        cometContext.setExpirationDelay(expirationDelay);
        registerService(LongPollingListenerFactory.class, new CometListenerFactory(cometContext));
    }

    @Override
    protected void stopBundle() throws Exception {
        LOG.info("stopping bundle: com.openexchange.drive.json.comet");
        try {
            CometContextService cometContextService = getService(CometContextService.class);
            if (null != cometContextService) {
                cometContextService.deregister(TOPIC);
            }
        } catch (RuntimeException e) {
            LOG.warn("Error unregistering comet context", e);
        }
        super.stopBundle();
    }

}
